notebookx - Fast, lightweight notebook conversion library
This library provides a unified representation for Jupyter notebooks and supports conversion between different notebook formats.
Example
use notebookx::{Notebook, Cell, NotebookFormat};
// Create a notebook programmatically
let mut notebook = Notebook::new();
notebook.cells.push(Cell::markdown("# Hello World"));
notebook.cells.push(Cell::code("print('Hello!')"));
// Serialize to ipynb format
let json = NotebookFormat::Ipynb.serialize(¬ebook).unwrap();Re-exports
pub use formats::NotebookFormat;
Modules
- formats
- Notebook format parsers and serializers.
Structs
- Cell
Metadata - Metadata associated with a cell.
- Clean
Options - Options for cleaning a notebook.
- Kernel
Spec - Kernel specification metadata.
- Language
Info - Language information metadata.
- Notebook
- A Jupyter notebook.
- Notebook
Metadata - Notebook-level metadata.
Enums
- Cell
- A cell in a Jupyter notebook.
- Mime
Data - Data for a single MIME type in an output.
- Multiline
String - A string that may be serialized as a single string or array of lines.
- Notebook
Error - Top-level error type for all notebookx operations.
- Output
- Output from executing a code cell.
- Parse
Error - Errors that can occur during notebook parsing.
- Serialize
Error - Errors that can occur during notebook serialization.
- Stream
Name - Stream name for stream outputs.
Type Aliases
- Mime
Bundle - A bundle of MIME-typed data representations.